import AsyncCache from "./cache";
import { HeightTile } from "./height-tile";
import { CancelablePromise, ContourTile, DemTile, Encoding, FetchResponse, IndividualContourTileOptions } from "./types";
import { Timer } from "./performance";
/**
 * Holds cached tile state, and exposes `fetchContourTile` which fetches the necessary
 * tiles and returns an encoded contour vector tiles.
 */
export interface DemManager {
    loaded: Promise<any>;
    fetchTile(z: number, x: number, y: number, timer?: Timer): CancelablePromise<FetchResponse>;
    fetchAndParseTile(z: number, x: number, y: number, timer?: Timer): CancelablePromise<DemTile>;
    fetchContourTile(z: number, x: number, y: number, options: IndividualContourTileOptions, timer?: Timer): CancelablePromise<ContourTile>;
}
/**
 * Caches, decodes, and processes raster tiles in the current thread.
 */
export declare class LocalDemManager implements DemManager {
    tileCache: AsyncCache<string, FetchResponse>;
    parsedCache: AsyncCache<string, DemTile>;
    contourCache: AsyncCache<string, ContourTile>;
    demUrlPattern: string;
    encoding: Encoding;
    maxzoom: number;
    timeoutMs: number;
    loaded: Promise<void>;
    decodeImage: (blob: Blob, encoding: Encoding) => CancelablePromise<DemTile>;
    constructor(demUrlPattern: string, cacheSize: number, encoding: Encoding, maxzoom: number, timeoutMs: number);
    fetchTile(z: number, x: number, y: number, timer?: Timer): CancelablePromise<FetchResponse>;
    fetchAndParseTile: (z: number, x: number, y: number, timer?: Timer) => CancelablePromise<DemTile>;
    fetchDem(z: number, x: number, y: number, options: IndividualContourTileOptions, timer?: Timer): CancelablePromise<HeightTile>;
    fetchContourTile(z: number, x: number, y: number, options: IndividualContourTileOptions, timer?: Timer): CancelablePromise<ContourTile>;
}
